This function plots a scatterplot of von Bertalanffy growth function parameters \(K\) vs \(L_{inf}\) (“Kimura plot”) with histograms.
LinfK_scatterhist(
res,
Linf.breaks = "Sturges",
K.breaks = "Sturges",
gridsize = rep(151, 2),
H = NULL,
shading = TRUE,
shading.cols = NULL,
dens.contour = TRUE,
probs = c(25, 50, 75, 95),
phi.contour = TRUE,
phi.levels = NULL,
phi.contour.col = 8,
phi.contour.lty = 2,
phi.contour.lwd = 1,
phi.contour.labcex = 0.75,
pt.pch = 16,
pt.col = adjustcolor(1, 0.25),
pt.cex = 0.5,
pt.bg = 4,
xlab = expression(italic("L")[infinity]),
ylab = expression(italic("K")),
...
)This function returns just the described plot.
Object of class data.frame, tbl_df, lfqBoot
or grotagBoot.
Arguments passed to hist
function to compute the breakpoints (argument breaks) for Linf and K
histograms respectively.
numeric 2-length vector specifying the resolution of
the grid.
Plug-in bandwidth object from Hpi (Default:
H = ks::Hpi(res[,c("Linf", "K")]))
logical. Do you want to colour 2D field of density
estimates? (Default TRUE)
Colors or color palette used for background shading of 2D
field of density estimates. No considered if shading = FALSE.
logical. Do you want to add contour lines?
(TRUE by default).
numeric Density probability cutoffs (in
by contours. By default probs = c(25, 50, 75, 95) and not considered
if dens.contour = FALSE.
logical. Do you want to display phi prime isolines?
(FALSE by default)
numeric vector that controls Phi prime values.
Omitted if phi.contour = FALSE and if NULL values will be
chosen automatically by the contour function.
Extra arguments used to control the color, line type, line width and labels size of the phi prime contour isolines.
Extra arguments to control type, color, size and background color of resampling points.
Labels for X and Y axis respectively.
Extra arguments passed to main plot function.
Isolines of growth performance (\(Phi’\)) can be plotted, as well as
bivariate 95
used for plotting is usually the result of a bootstrapped growth analysis
(i.e. a lfqBoot object generated by fishboot functions such
as ELEFAN_SA_boot, ELEFAN_GA_boot, grotag_boot, or
grolenage_boot).
If NULL, it will be defined as colorRampPalette(c("white", blues9))(1e3).
data(alba_boot) # lfqBoot object
LinfK_scatterhist(res = alba_boot)
data(bonito_boot) # grotagBoot object
LinfK_scatterhist(res = bonito_boot)
Run the code above in your browser using DataLab